{ pkgs, username, ... }: {

    services.cage = {
        enable = true;
        user = username;
    };
    
    environment.etc = {
        "background.jpg".source = ./background.jpg;
    };
    
    programs.regreet = {
        enable = true;
        settings = {
            background = {
                path = "/etc/background.jpg";
                fit = "Contain";
            };
            

            GTK = {
                application_prefer_dark_theme = true;
                cursor_theme_name = "Adwaita";
                font_name = "Cantarell 16";
                icon_theme_name = pkgs.material-design-icons;
                theme_name = "Adwaita";
            };

            commands = {
                reboot = ["systemctl" "reboot"];
                poweroff = ["systemctl" "poweroff"];
                x11_prefix = ["startx" "/usr/bin/env"];
            };

            widget.clock = {
                format = "%A %d.%m.%Y %T"; # Sunday 30.03.2025 11:25:17
                resolution = "500ms";
                timezone = "Europe/Berlin";
                label_width = 150;
            };
            
            theme = {
                package = pkgs.gnome-themes-extra;
                name = "Adwaita";
            };
            
            iconTheme.package = pkgs.vimix-icon-theme;

            cursorTheme = {
                package = pkgs.nordzy-cursor-theme;
                name = "Nordzy-cursors";
            };
            
            font = {
                package = pkgs.nerd-fonts.roboto-mono;
                name = "RobotoMono";
            };
        };
    };
}
